@@ -115,7 +115,7 @@ class Citation:
                 name=self.schema.name,
                 regex=regex,
                 idForms=self.schema.idForms,
-                URL=self.schema.URL,
+                URL=self.schema.URL if hasattr(self.schema, 'URL') else None,
                 mutations=self.schema.mutations,
                 substitutions=self.schema.substitutions,
                 parent_citation=self,
@@ -480,7 +480,7 @@ class Schema:
     def __init__(self,
         name: str,
         regex,
-        URL,
+        URL=None,
         broadRegex=None,
         idForms: list=[],
         shortForms: list=[],
